<?php
/**
 * Template Name: Product Template
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @Package Aabbe
 * @since 1.0.0
 * 
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}


get_header();
$download_id = get_the_ID();

if ( is_active_sidebar( 'download' ) ) {
    $aabbe_layout      = 'col-md-12';
    $aabbe_post_layout = 'col-md-4 col-sm-6 col-xs-12';
}else{
    $aabbe_layout      = 'col-md-12';
    $aabbe_post_layout = 'col-md-4 col-sm-6 col-xs-12';
}

$orderby        = ( isset( $_GET['orderby'] ) ) ? $_GET['orderby'] : null;
$paged          = ( get_query_var( 'paged')) ? get_query_var( 'paged') : 1;
$posts_per_page = 12;

if ( ! isset( $wp_query->query['orderby'] ) ) {
    $args = array(
        'order'          => 'DESC',
        'post_type'      => 'download',
        'paged'          => $paged,
        'posts_per_page' => $posts_per_page,
    );
}else{
    switch ($wp_query->query['orderby']) {
        case 'newness_asc':
            $args = array(
                'orderby'        => 'newness_asc',
                'order'          => 'ASC',
                'post_type'      => 'download',
                'paged'          => $paged,
                'posts_per_page' => $posts_per_page,
            );
        break;
        case 'newness_desc':
            $args = array(
                'orderby'        => 'newness_desc',
                'order'          => 'DESC',
                'post_type'      => 'download',
                'paged'          => $paged,
                'posts_per_page' => $posts_per_page,
            );
        break;
        case 'sales':
            $args = array(
                'meta_key'       =>'_edd_download_sales',
                'order'          => 'DESC',
                'orderby'        => 'meta_value_num',
                'post_type'      => 'download',
                'paged'          => $paged,
                'posts_per_page' => $posts_per_page,
            );
        break;
        case 'price_asc':
            $args = array(
                'meta_key'       =>'edd_price',
                'order'          => 'ASC',
                'orderby'        => 'meta_value_num',
                'post_type'      => 'download',
                'paged'          => $paged,
                'posts_per_page' => $posts_per_page,
            );
        break;            
        case 'price_desc':
            $args = array(
                'meta_key'       =>'edd_price',
                'order'          => 'DESC',
                'orderby'        => 'meta_value_num',
                'post_type'      => 'download',
                'paged'          => $paged,
                'posts_per_page' => $posts_per_page,
            );
        break;            
        case 'title_asc':
            $args = array(
                'orderby'        => 'title',
                'order'          => 'ASC',
                'post_type'      => 'download',
                'paged'          => $paged,
                'posts_per_page' => $posts_per_page,
            );
        break;            
        case 'title_desc':
            $args = array(
                'orderby'        => 'title',
                'order'          => 'DESC',
                'post_type'      => 'download',
                'paged'          => $paged,
                'posts_per_page' => $posts_per_page,
            );
        break;
    }
}
$temp     = $wp_query; $wp_query = null;
$wp_query = new WP_Query(); $wp_query->query($args);

?>
<?php
    if (function_exists('aabbe_title')) {
        aabbe_title();
    }
?>

    <div class="content-area section-padding">
        <div class="download__searform__area">
            <div class="container">
                <div class="product__search__filter__area">
                    <div class="row">
                        <div class="col-md-8">
                            <div class="download__search__form">
                                <?php get_template_part( 'searchform-download' ); ?>                            
                            </div>
                        </div>
                        <div class="col-md-4">
                            <?php
                                if ( function_exists('aabbe_download_orderby_shorting') ) {
                                    aabbe_download_orderby_shorting();
                                }
                            ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="container">
            <div class="row">
                <div class="<?php echo esc_attr( $aabbe_layout ); ?>">
                    <div class="download__grid">
                        <div class="row">

                            <?php if ( $wp_query->have_posts() ) : ?>  

                            <?php while ( $wp_query->have_posts() ) : $wp_query->the_post(); ?>
                                <div class="<?php echo esc_attr( $aabbe_post_layout ); ?>">
                               
                                    <?php get_template_part( 'edd/content/content-download', get_post_format() ); ?>
                                    
                                </div>
                            <?php endwhile; ?>

                            <?php else: ?>

                            <div class="col-md-12">
                                <?php get_template_part( 'template-parts/content/content', 'none' ); ?>
                            </div>

                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="post-pagination">                        
                                <?php aabbe_custom_pagination(); ?>
                            </div>  
                        </div>
                    </div>
                </div>
                <!-- End Content -->
            </div>
        </div>
    </div>
<?php
get_footer();