<?php
/**
 * EDD CUSTOM SETUP
 *
 * Learn more: http://docs.easydigitaldownloads.com/
 *
 */

/*---------------------------------
    ADD POST FORMAT FOR EDD
----------------------------------*/
if ( !function_exists('aabbe_edd_setup') ) {
    function aabbe_edd_setup(){

        add_post_type_support( 'download', 'post-formats' );
        add_theme_support( 'post-formats',array(
            'link',
            'audio',
            'image',
            'gallery',
            'video',
        ));
        
        add_image_size( 'aabbe-edd-thumb', 80, 80, array( 'center', 'center' ) );
        add_image_size( 'aabbe-edd-preview', 950, 600, array( 'center', 'center' ) );
    }
}
add_action( 'after_setup_theme','aabbe_edd_setup' );


/*--------------------------------
    REGISTER EDD WIDGETS AREA
---------------------------------*/
if ( !function_exists('aabbe_edd_widget_init') ) {
    function aabbe_edd_widget_init(){
        register_sidebar( array(
            'name'          => esc_html__( 'Download Sidebar', 'aabbe' ),
            'id'            => 'download',
            'description'   => esc_html__( 'Paste your widget download sidebar widget here.','aabbe' ),
            'before_widget' => '<div id="%1$s" class="single-widgets widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        ));
    }
}
add_action( 'widgets_init', 'aabbe_edd_widget_init' );


/*----------------------------------
    EDD SCRIPTS LOAD.
-----------------------------------*/
function aabbe_edd_scripts() {
    wp_enqueue_style( 'lity', AABBE_ROOT_URI . '/edd/css/lity.min.css' );
    wp_enqueue_style( 'plyr', AABBE_ROOT_URI . '/edd/css/plyr.css' );
    wp_enqueue_style( 'tooltipster', AABBE_ROOT_URI .'/edd/css/tooltipster.bundle.min.css', array(), '2.0.0', 'all' );
    wp_enqueue_style( 'edd-active', AABBE_ROOT_URI . '/edd/css/edd-active.css' );

    wp_enqueue_script( 'lity', AABBE_ROOT_URI . '/edd/js/lity.min.js', array('jquery'), '', true );
    wp_enqueue_script( 'plyr', AABBE_ROOT_URI . '/edd/js/plyr.min.js', array('jquery'), '', true );
    wp_enqueue_script( 'wavesurfer', AABBE_ROOT_URI . '/edd/js/wavesurfer.min.js', array('jquery'), '', true );
    wp_enqueue_script( 'tooltipster', AABBE_ROOT_URI . '/edd/js/tooltipster.bundle.min.js', array('jquery'), '1.0.0', true );
    wp_enqueue_script( 'edd-active', AABBE_ROOT_URI . '/edd/js/edd-active.js', array('jquery'), '', true );
}
add_action( 'wp_enqueue_scripts', 'aabbe_edd_scripts' );

if ( class_exists( 'Easy_Digital_Downloads' ) ) :

    /*----------------------------------
        AUTHOR URL
    -----------------------------------*/
    function aabbe_fes_author_url( $author = null ) {
        global $post;
        $author_id = $post->post_author;
        if ( ! $author ) {
            $author = wp_get_current_user();
        }else{
            $author = new WP_User( $author );
        }

        if ( class_exists( 'EDD_Front_End_Submissions' ) && aabbe_any_switch('enable_custom_vendor_url') == true ) {
            return EDD_FES()->vendors->get_vendor_store_url( $author->ID );
        }else{
            return add_query_arg( 'author_downloads', 'true', get_author_posts_url( get_the_author_meta('ID',$author_id)) );
        }
    }


    /*----------------------------------
        VENDOR LAVEL
    -----------------------------------*/
    function aabbe_product_author_level(){

        global $wpdb;
        global $post;
        if ( is_singular( 'download' ) ) {
            $author = new WP_User( $post->post_author );
        } else {
            $author = fes_get_vendor();
        }

        if ( ! $author ) {
            $author = get_current_user_id();
        }
        $author_id    = get_the_author_meta( 'ID' );
        $author_level = '';

        $results = $wpdb->get_results( 
            $wpdb->prepare( "SELECT sales_value FROM {$wpdb->prefix}fes_vendors WHERE user_id = %d", $author_id )
        );
        if ($results) {
            $sales_value = abs($results[0]->sales_value);
        }else{
            $sales_value = 0;
        }

        if ( $sales_value == 0 ) {
            $author_level = '<span class="vendor__author__level author_level_0" title="'.sprintf( esc_attr__( 'Author earned %s', 'aabbe' ), edd_currency_filter( 0 ) ).'">'.esc_html__( 'Level 0', 'aabbe' ).'</span>';
        }elseif ($sales_value > 200000) {
            $author_level = '<span class="vendor__author__level author_level_10" title="'.sprintf(esc_attr__( 'Author earned more then (%s)', 'aabbe' ), edd_currency_filter( 200000 )).'">'.esc_html__( 'Level 10', 'aabbe' ).'</span>';
        }elseif ($sales_value > 150000) {
            $author_level = '<span class="vendor__author__level author_level_9" title="'.sprintf(esc_attr__( 'Author earned more then (%s)', 'aabbe' ), edd_currency_filter( 150000 )).'">'.esc_html__( 'Level 9', 'aabbe' ).'</span>';
        }elseif ($sales_value > 100000) {
            $author_level = '<span class="vendor__author__level author_level_8" title="'.sprintf(esc_attr__( 'Author earned more then (%s)', 'aabbe' ), edd_currency_filter( 100000 )).'">'.esc_html__( 'Level 8', 'aabbe' ).'</span>';
        }elseif ($sales_value > 70000) {
            $author_level = '<span class="vendor__author__level author_level_7" title="'.sprintf(esc_attr__( 'Author earned more then (%s)', 'aabbe' ), edd_currency_filter( 70000 )).'">'.esc_html__( 'Level 7', 'aabbe' ).'</span>';
        }elseif ($sales_value > 40000) {
            $author_level = '<span class="vendor__author__level author_level_6" title="'.sprintf(esc_attr__( 'Author earned more then (%s)', 'aabbe' ), edd_currency_filter( 40000 )).'">'.esc_html__( 'Level 6', 'aabbe' ).'</span>';
        }elseif ($sales_value > 10000) {
            $author_level = '<span class="vendor__author__level author_level_5" title="'.sprintf(esc_attr__( 'Author earned more then (%s)', 'aabbe' ), edd_currency_filter( 10000 )).'">'.esc_html__( 'Level 5', 'aabbe' ).'</span>';
        }elseif ($sales_value > 5000) {
            $author_level = '<span class="vendor__author__level author_level_4" title="'.sprintf(esc_attr__( 'Author earned more then (%s)', 'aabbe' ), edd_currency_filter( 5000 )).'">'.esc_html__( 'Level 4', 'aabbe' ).'</span>';
        }elseif ($sales_value > 1000) {
            $author_level = '<span class="vendor__author__level author_level_3" title="'.sprintf(esc_attr__( 'Author earned more then (%s)', 'aabbe' ), edd_currency_filter( 1000 )).'">'.esc_html__( 'Level 3', 'aabbe' ).'</span>';
        }elseif ($sales_value > 100) {
            $author_level = '<span class="vendor__author__level author_level_2" title="'.sprintf(esc_attr__( 'Author earned more then (%s)', 'aabbe' ), edd_currency_filter( 100 )).'">'.esc_html__( 'Level 2', 'aabbe' ).'</span>';
        }elseif ( $sales_value > 0 ) {
            $author_level = '<span class="vendor__author__level author_level_1" title="'.sprintf(esc_attr__( 'Author earned more then (%s)', 'aabbe' ), edd_currency_filter( 0 )).'">'.esc_html__( 'Level 1', 'aabbe' ).'</span>';
        }
        return $author_level;
    }

    /*--------------------------------------------
    ADD VENDOR ARCHIVE TEMPLATE FOR VENDOR ARCHIVE PAGE
    -------------------------------------------*/
    function aabbe_vendor_template( $template ) {

        if ( ! function_exists( 'EDD_FES' ) ) {
            return $template;
        }

        $vendor_page = EDD_FES()->helper->get_option( 'fes-vendor-page', false );
        if ( ! is_page( $vendor_page ) ) {
            return $template;
        }

        $vendor = get_query_var( 'vendor' );
        if (( $vendor ) ) {
            return locate_template( 'vendor-archive.php' );
        }

        return $template;
    }
    add_filter( 'template_include', 'aabbe_vendor_template' );

    /*--------------------------------------------
        REVIEW WALKER TEMPLATE
    --------------------------------------------*/
    if ( class_exists('EDD_Reviews') ) {
        require_once( AABBE_ROOT . '/edd/review/class-walker-edd-review.php');

        function aabbe_edd_comments_walker($args){

        $args['walker'] =  new aabbe_Walker_EDD_Review();
        return $args;

        }
        add_filter( 'edd_reviews_render_reviews_args', 'aabbe_edd_comments_walker' );
    }

    /*--------------------------------------------
        EDD PRODUCT STAR RATING
    ---------------------------------------------*/
    function aabbe_edd_rating( $ratting_count = false, $ratting_text = '' ) { 

        if ( ! function_exists( 'edd_reviews' ) ){
            return;
        }
        ?>
        <?php
            global $wp_query;
            global $post;
            $postID     = $post->ID;
            $starRating = null;
            if( class_exists( 'EDD_Reviews' ) ) {
                $starRating = edd_reviews()->average_rating(false);
                $starRating = (round($starRating*2))*10;
            }
        ?>
        <div title="<?php echo esc_attr($starRating/20);?> <?php esc_attr_e('out of 5','aabbe');?>" class="download__star__rating">
            <div class="rating">
                <i class="fa fa-star" data-vote="1"></i>
                <i class="fa fa-star" data-vote="2"></i>
                <i class="fa fa-star" data-vote="3"></i>
                <i class="fa fa-star" data-vote="4"></i>
                <i class="fa fa-star" data-vote="5"></i>
            </div>
            <div class="rated" style="width:<?php echo esc_attr($starRating);?>%">
                <i class="fa fa-star" data-vote="1"></i>
                <i class="fa fa-star" data-vote="2"></i>
                <i class="fa fa-star" data-vote="3"></i>
                <i class="fa fa-star" data-vote="4"></i>
                <i class="fa fa-star" data-vote="5"></i>
            </div>
        </div>
        <?php if( $ratting_count == true ) : ?>
            <div class="count__ratting">
                ( <?php echo esc_html( edd_reviews()->count_reviews() );?><?php if(!empty($ratting_text)){echo esc_html( $ratting_text );} ?> )
            </div>
        <?php endif; ?>
    <?php
    }

    /*-------------------------------------------
        AVARAGE RATING
    --------------------------------------------*/
    function aabbe_avarage_rating() {
        if ( ! function_exists( 'edd_reviews' ) ){
            return;
        }
        
        /*-------------------------------------------
            GET THE AVERAGE RATING FOR THIS DOWNLOAD
        --------------------------------------------*/
        $average_rating = edd_reviews()->average_rating( false );    
        $rating         = $average_rating;
        $ratingclass    = (int) edd_reviews()->average_rating( false );
        ob_start(); ?>
            <div itemprop="reviewRating" itemscope itemtype="http://schema.org/Rating" class="star-rating">
                <div class="edd_reviews_rating_box <?php if ($rating==4.5){  ?>four-half-rating<?php }?> <?php echo esc_attr__( 'stars', 'aabbe' ).$ratingclass; ?>" role="img">
                    <div class="edd_star_rating" aria-label="<?php echo esc_attr( $rating )  . ' ' . esc_attr__( 'stars', 'aabbe' ); ?>">
                        <span class="rating-stars"></span>
                        <span class="rating-stars"></span>
                        <span class="rating-stars"></span>
                        <span class="rating-stars"></span>
                        <span class="rating-stars-last"></span>
                        <p>(<?php echo esc_html( edd_reviews()->count_reviews() );?>)</p>
                    </div>
                </div>
                <div style="display:none" itemprop="reviewRating" itemscope itemtype="http://schema.org/Rating">
                    <meta itemprop="worstRating" content="1"/>
                    <span itemprop="ratingValue"><?php echo esc_attr( $rating ); ?></span>
                    <span itemprop="bestRating">5</span>
                </div>
            </div>
        <?php
        $rating_html = ob_get_clean();
        return $rating_html;
    }

    /*--------------------------------------------
        EDD SINGLE TOTAL REVIEW COUNT
    ----------------------------------------------*/
    if( class_exists( 'EDD_Reviews' ) ) {
        function aabbe_edd_count_review() {
            echo esc_html( edd_reviews()->count_reviews() );  
        }
    }

    /*--------------------------------------------
        EDD TOTAL REVIEW COUNT
    ----------------------------------------------*/
    if( class_exists( 'EDD_Reviews' ) ) {
        function aabbe_edd_count_total_review() {
            echo esc_html(edd_reviews()->average_rating(false));  
        }
    }

    /*--------------------------------------------
        EDD VENDOR TOTAL REVIEW COUNT
    ----------------------------------------------*/
    if( class_exists( 'EDD_Reviews' ) ) {
        function aabbe_edd_count_vendor_review() {
            echo esc_html( edd_reviews()->count_reviews() );  
        }
    }

    /*----------------------------------------
        EDD TOTAL FILE SIZE
    -----------------------------------------*/
    function aabbe_edd_show_file_sizes( $post_id ) {
        $files    = edd_get_download_files( $post_id, null );
        $decimals = 2;
        $sz       = 'BKMGTP';

        echo '<ul>';
        foreach( $files as $file ){
            $bytes  = filesize( get_attached_file( $file['attachment_id'] ) );
            $factor = floor((strlen($bytes) - 1) / 3);
            echo '<li>' . $file['name'] . ' - ' . sprintf( "%.{$decimals}f", $bytes / pow( 1024, $factor) ) . $sz[$factor] . '</li>';
        }
        echo '</ul>';
    }

    function aabbe_edd_show_total_file_size( $post_id ) {
        $files           = edd_get_download_files( $post_id, null );
        $decimals        = 2;
        $sz              = 'BKMGTP';
        $bytes           = 0;
        $total_file_size = 0;
        foreach( $files as $file ){
            $bytes           += filesize( get_attached_file( $file['attachment_id'] ) );
            $factor          = floor((strlen($bytes) - 1) / 3);
            $total_file_size = sprintf( "%.{$decimals}f", $bytes / pow( 1024, $factor ) ) . $sz[$factor];
        }

        return $total_file_size;
    }

endif;

/*--------------------------------------------------
    EDD COMMENTS SUPPORTS
----------------------------------------------------*/
function aabbe_edd_add_comments_support($supports){
    $supports[] = 'comments';
    return $supports;
}
add_filter('edd_download_supports', 'aabbe_edd_add_comments_support');

/*-------------------------------
    REMOVE PREFIX FROM ARCHIVE
---------------------------------*/
function aabbe_remove_archive_prefix($title){
    if ( is_category() ){
        $title = single_cat_title( '', false );
    }elseif ( is_tag() ) {
        $title = single_tag_title( '', false );
    }elseif ( is_author() ) {
        $title = '<span class="vcard">' . get_the_author() . '</span>' ;
    }elseif ( is_tax() ) {
        $title = sprintf( __( '%1$s','aabbe' ), single_term_title( '', false ) );
    }elseif ( is_post_type_archive() ) {
        $title = post_type_archive_title( '', false );
    }
    return $title;
}
add_filter( 'get_the_archive_title', 'aabbe_remove_archive_prefix' );

/*----------------------------------------------
    Add wrapper class to EDD [download] shortcode
------------------------------------------------*/
function aabbe_edd_download_wrap( $class, $atts ){
    return 'download__default__wrapper download__wrapper ' . $class;
}
add_filter( 'edd_downloads_list_wrapper_class', 'aabbe_edd_download_wrap', 10, 2 );

/*----------------------------------------------
    REMOVE WRAPER SCHIMA
-----------------------------------------------*/
remove_action( 'loop_end', 'edd_microdata_wrapper_close', 10 );
remove_action( 'loop_start', 'edd_microdata_wrapper_open', 10 );

/*-----------------------------------------------
    EDD Single Item Class
-------------------------------------------------*/
if ( !function_exists('aabbe_download_post_class') ) {
   function aabbe_download_post_class( $classes ) {
    
        global $post;
        if ( 'download' === get_post_type() ) {
            if ( is_single() ) {
                $classes[] = 'single__grid__download__item';
            }else{
                $classes[] = 'grid__download__item mb30';
            }
        }
        return $classes;
    }
}
add_filter( 'post_class', 'aabbe_download_post_class' );

/*--------------------------------
    BECOME VENDOR PAGE CLASS
----------------------------------*/
function aabbe_add_body_class($classes){ 
    $query_object = get_queried_object();
     
    if ( !(is_home() || is_front_page()) && 'page' == get_post_type() && '[fes_vendor_dashboard]' == $query_object->post_content ) {
        return array_merge( $classes, array( 'edd__become__vendor' ) );
    }else{
        return $classes; 
    }
}
add_filter( 'body_class','aabbe_add_body_class' );

/*---------------------------------------------
    Show the list of products when the cart is empty
-----------------------------------------------*/
function checkout_empty_cart_template() {

    echo ('
        <div class="download__empty__cart">                        
            <div class="empty_cart_icon">
                <i class="fa fa-shopping-cart"></i>
            </div>
            <h4>'.esc_html__( 'Your Cart Is Empty', 'aabbe' ).'</h4>
        </div>
    ');
}
add_filter( 'edd_cart_empty', 'checkout_empty_cart_template' );

/*------------------------------------------------
    CHANGE CHECKOUT PAGE IMAGE SIZE
--------------------------------------------------*/
function aabbe_edd_checkout_image_size( $array ) {
    return array( 120, 80 );
}
add_filter( 'edd_checkout_image_size', 'aabbe_edd_checkout_image_size', 10, 1 );

/*-------------------------------------------------
    EDD WISHT LIST
---------------------------------------------------*/
if ( class_exists( 'EDD_Wish_Lists' ) ) {

    function aabbe_remove_favorites() {
        /*remove from default location*/
        remove_action( 'edd_purchase_link_end', 'edd_favorites_load_link' );
        remove_action( 'edd_purchase_link_top', 'edd_favorites_load_link' );
    }
    add_action( 'template_redirect', 'aabbe_remove_favorites' );

    /**
     * Remove standard favorite links
     * @return [type] [description]
     */
    function aabbe_wisthlist_load() {
        /*remove standard add to wish list link*/
        remove_action( 'edd_purchase_link_top', 'edd_favorites_load_link' );

        /*adding new link*/
        add_action( 'edd_purchase_link_top', 'edd_wl_load_wish_list_link' );
    }
    add_action( 'template_redirect', 'aabbe_wisthlist_load' );
}


/*----------------------------------------------------
    EMAIL TEMPLATE
-----------------------------------------------------*/
function aabbe_edd_register_email_template( $templates ) {
    $templates['aabbe-template'] = esc_html__( 'Aabbe Simple Temlate', 'aabbe' );
    return $templates;
}
add_filter( 'edd_email_templates', 'aabbe_edd_register_email_template' );

function aabbe_edd_email_tags() {

    $aabbe_email_tags = array(
        array(
            'tag'         => 'aabbe_download_list',
            'description' => esc_html__( 'A list of download links for each download purchased', 'aabbe' ),
            'function'    => 'aabbe_get_edd_email_tags'
        ),
    );

    /* Apply edd_email_tags filter */
    $aabbe_email_tags = apply_filters( 'edd_email_tags', $aabbe_email_tags );

    /* Add email tags */
    foreach ( $aabbe_email_tags as $email_tag ) {
        edd_add_email_tag( $email_tag['tag'], $email_tag['description'], $email_tag['function'] );
    }
}
add_action( 'edd_add_email_tags', 'aabbe_edd_email_tags' );


/*----------------------------------------------------
 * Email template tag: download_list
 * A list of download links for each download purchased
 *
 * @param int $payment_id
 *
 * @return string download_list
-----------------------------------------------------*/
function aabbe_get_edd_email_tags( $payment_id ) {
    $payment               = new EDD_Payment( $payment_id );
    
    $payment_data          = $payment->get_meta();
    $aabbe_download_list = '<div class="aabbe__simple__ui">';
    $cart_items            = $payment->cart_details;
    $email                 = $payment->email;

    if ( $cart_items ) {
        $show_names = apply_filters( 'edd_email_show_names', true );
        $show_links = apply_filters( 'edd_email_show_links', true );

        foreach ( $cart_items as $item ) {

            if ( edd_use_skus() ) {
                $sku = edd_get_download_sku( $item['id'] );
            }

            if ( edd_item_quantities_enabled() ) {
                $quantity = $item['quantity'];
            }

            $price_id = edd_get_cart_item_price_id( $item );
            if ( $show_names ) {
                $aabbe_download_list .= '<div class="every-product-term-thg"><div class="email-first-pd-tf">';
                $title = '<p class="m-i-title">' . get_the_title( $item['id'] ) . '';
                if ( current_theme_supports( 'post-thumbnails' ) && has_post_thumbnail( $item['id'] ) ) {
                    $aabbe_download_list .= get_the_post_thumbnail( $item['id'], apply_filters( 'aabbe-email-thumbnail', array( 75,50 ) ) );
                }
                if ( ! empty( $quantity ) && $quantity > 1 ) {
                    $title .= "&nbsp;&ndash;" . __( 'x', 'aabbe' ) . '' . $quantity;
                }

                if ( ! empty( $sku ) ) {
                    $title .= "&nbsp;&ndash;&nbsp;" . __( 'SKU', 'aabbe' ) . ': ' . $sku;
                }

                if( ! empty( $price_id ) && 0 !== $price_id ){
                    $title .= "&nbsp;&ndash;&nbsp;" . edd_get_price_option_name( $item['id'], $price_id, $payment_id );
                }

                $aabbe_download_list .= ' '. apply_filters( 'edd_email_receipt_download_title', $title, $item, $price_id, $payment_id ) . '</p></div><div class="extra-information-email-df">';
            }
            $aabbe_download_list .= edd_cart_item_price( $item['id'], $item['options']);
            $files = edd_get_download_files( $item['id'], $price_id );

            if ( ! empty( $files ) ) {

                foreach ( $files as $filekey => $file ) {

                    if ( $show_links ) {
                        $aabbe_download_list .= '<div class="aabbe-email-p-td">';
                        $file_url              = edd_get_download_file_url( $payment_data['key'], $email, $filekey, $item['id'], $price_id );
                        $aabbe_download_list .= '<a href="' . esc_url_raw( $file_url ) . '">' . Download . '</a>';
                        $aabbe_download_list .= '</div></div>';
                    } else {
                        $aabbe_download_list .= '<div>';
                        $aabbe_download_list .= edd_get_file_name( $file );
                        $aabbe_download_list .= '</div></div>';
                    }

                }

            }elseif ( edd_is_bundled_product( $item['id'] ) ) {

                $bundled_products = apply_filters( 'edd_email_tag_bundled_products', edd_get_bundled_products( $item['id'], $price_id ), $item, $payment_id, 'download_list' );

                foreach ( $bundled_products as $bundle_item ) {

                    $aabbe_download_list .= '<div class="edd_bundled_product"><p class="m-i-title">' . get_the_title( $bundle_item ) . '</p></div>';

                    $download_files = edd_get_download_files( edd_get_bundle_item_id( $bundle_item ), edd_get_bundle_item_price_id( $bundle_item ) );

                    foreach ( $download_files as $filekey => $file ) {
                        if ( $show_links ) {
                            $aabbe_download_list .= '<div>';
                            $file_url              = edd_get_download_file_url( $payment_data['key'], $email, $filekey, $bundle_item, $price_id );
                            $aabbe_download_list .= '<a href="' . esc_url( $file_url ) . '">' . Download . '</a>';
                            $aabbe_download_list .= '</div>';
                        } else {
                            $aabbe_download_list .= '<div>';
                            $aabbe_download_list .= edd_get_file_name( $file );
                            $aabbe_download_list .= '</div>';
                        }
                    }
                }
            } else {

                $no_downloads_message = apply_filters( 'edd_receipt_no_files_found_text', __( 'No files.', 'aabbe' ), $item['id'] );
                $no_downloads_message = apply_filters( 'edd_email_receipt_no_downloads_message', $no_downloads_message, $item['id'], $price_id, $payment_id );

                if ( ! empty( $no_downloads_message ) ){
                    $aabbe_download_list .= '<div>';
                    $aabbe_download_list .= $no_downloads_message;
                    $aabbe_download_list .= '</div>';
                }
            }

            if ( '' != edd_get_product_notes( $item['id'] ) ) {
                $aabbe_download_list .= ' &mdash; <small>' . edd_get_product_notes( $item['id'] ) . '</small>';
            }


            if ( $show_names ) {
                $aabbe_download_list .= '</div>';
            }
        }
    }
    $aabbe_download_list .= '</div>';
    $payment               = new EDD_Payment( $payment_id );
    $subtotal              = edd_currency_filter( edd_format_amount( $payment->subtotal ), $payment->currency );
    $tax                   = edd_currency_filter( edd_format_amount( $payment->tax ), $payment->currency );
    $price                 = edd_currency_filter( edd_format_amount( $payment->total ), $payment->currency );
    $aabbe_download_list .= '<div style="overflow:hidden;padding-bottom:15px;">';
    $aabbe_download_list .= '<div class="bottom-payment-gateway-email">';
    $aabbe_download_list .= '<span>Purchased via '. edd_get_gateway_checkout_label( $payment->gateway ). '</span>';
    $aabbe_download_list .= '<span>at '. date_i18n( get_option( 'date_format' ), strtotime( $payment->date ) ). '</span>';
    $aabbe_download_list .= '</div>';
    $aabbe_download_list .= '<ul class="bottom-tag-detailsout">';
    
    $aabbe_download_list .= '<li><span>Sub Total:</span> ' . html_entity_decode( $subtotal, ENT_COMPAT, 'UTF-8' ).'</li>';
    $aabbe_download_list .= '<li><span>Tax: </span>' . html_entity_decode(  $tax, ENT_COMPAT, 'UTF-8' ).'</li>';
    $aabbe_download_list .= '<li><strong class="strong-caps-left">Total Payment: </strong><strong>' . html_entity_decode(  $price, ENT_COMPAT, 'UTF-8' ).'</strong></li>';
    $aabbe_download_list .= '</ul>';
    $aabbe_download_list .= '</div>';
    return $aabbe_download_list;
}


/*--------------------------------
    DONWLOAD EMAIL FIELDS
----------------------------------*/
if ( class_exists( 'Easy_Digital_Downloads' ) ) :

    function aabbe_email_custom_fields( $settings ) {

        global $edd_options;
        if ( array_key_exists( 'email_template' , $edd_options ) ) {
            if ($edd_options['email_template'] == 'aabbe-template') {
                $aabbe_extra_settings = array(
                    array(
                        'id'         => 'aabbe_simple_mailing_address',
                        'name'       => esc_html__( 'Add Mailing Address', 'aabbe' ),
                        'desc'       => esc_html__( 'add a mailing address for footer', 'aabbe' ),
                        'type'       => 'text',
                    ),
                    array(
                        'id'         => 'aabbe_header_cover',
                        'name'       => esc_html__( 'Add Header Cover Image', 'aabbe' ),
                        'desc'       => esc_html__( 'upload header cover image', 'aabbe' ),
                        'type'       => 'upload',
                    ),
                );
            }
        } else {
            $aabbe_extra_settings = array();
        }

        return array_merge( $settings, $aabbe_extra_settings );
    }
    add_filter( 'edd_settings_emails', 'aabbe_email_custom_fields' );

    /*----------------------------------
        SALE COUNT
    -----------------------------------*/
    if( ! function_exists( 'aabbe_get_edd_sale_count' ) ){
        function aabbe_get_edd_sale_count($postID){
            return get_post_meta( $postID, '_edd_download_sales', true );
        }
    }

    function edd_count_total_file_downloads(){
        global $edd_logs;
        return $edd_logs->get_log_count( null, 'file_download' );
    }

    /*--------------------------------------
        EDD REMOVE PRICE DECIMALS
    ----------------------------------------*/
    function aabbe_edd_remove_decimals( $decimals ) {
        return 0;
    }
    add_filter( 'edd_format_amount_decimals', 'aabbe_edd_remove_decimals' );

    /*---------------------------------------
        EDD REMOVE PURCHASE LINK FROM CONTENT
    -----------------------------------------*/
    remove_action( 'edd_after_download_content', 'edd_append_purchase_link' );

    /*---------------------------------------
        EDD DISABLE DEFAULT PAGINATION
    ----------------------------------------*/
    remove_action( 'edd_downloads_list_after', 'edd_downloads_pagination', 10, 3 );

    /*----------------------------------------
        EDD CUSOTOM PAGINATION ADD
    ------------------------------------------*/
    /**
     * Load the pagination for the [downloads] shortcode.
     *
     * @since 2.9.8
     *
     * @param array  $atts The [downloads] shortcode attributes.
     * @param object $downloads The WP_Query.
     * @param array  $query EDD's array of attributes used to construct the main WP_Query.
     */
    function aabbe_edd_downloads_pagination( $atts, $downloads, $query ) {
        if ( filter_var( $atts['pagination'], FILTER_VALIDATE_BOOLEAN ) ) {
            $args = array(
                'type'    => 'download',
                'format'  => '?paged=%#%',
                'current' => max( 1, $query['paged'] ),
                'total'   => $downloads->max_num_pages
            );

            if ( is_single() ) {
                $args['base'] = get_permalink() . '%#%';
            } else {
                $big          = 999999;
                $search_for   = array( $big, '#038;' );
                $replace_with = array( '%#%', '&' );
                $args['base'] = str_replace( $search_for, $replace_with, get_pagenum_link( $big ) );
            }

            $args = apply_filters( 'edd_download_pagination_args', $args, $atts, $downloads, $query );

            echo aabbe_edd_pagination( $args );
        }
    }
    add_action( 'edd_downloads_list_after', 'aabbe_edd_downloads_pagination', 10, 3 );

    /**
     * Build pagination
     *
     * @since 2.9.8
     * 
     * @param array $args The arguments used to build the pagination.
     */
    function aabbe_edd_pagination( $args = array() ) {

        $big = 999999;

        $defaults = array(
            'base'    => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
            'format'  => '?paged=%#%',
            'current' => max( 1, get_query_var( 'paged' ) ),
            'type'    => '',
            'total'   => '',
        );

        $args = wp_parse_args( $args, $defaults );

        $type  = $args['type'];
        $total = $args['total'];

        // Type and total must be specified.
        if ( empty( $type ) || empty( $total ) ) {
            return false;
        }

        $pagination = paginate_links(
            array(
                'prev_text'          => '<i class="ti-arrow-left"></i>',
                'next_text'          => '<i class="ti-arrow-right"></i>',
                'screen_reader_text' => ' ',
                'mid_size'           => 1,
                'base'               => $args['base'],
                'format'             => $args['format'],
                'current'            => $args['current'],
                'total'              => $total,
                'type'               => 'list',
            )
        );

        if ( ! empty( $pagination ) ) : ?>
            <div class="post-pagination">
                
            <nav id="edd_<?php echo esc_attr( $type ); ?>_pagination" class="navigation pagination aabbe__product__pagination">
                <div class="nav-links">
                    <?php echo wp_kses_post( $pagination ); ?>
                </div>
            </nav>
            </div>
        <?php endif;
    }

endif;

/*------------------------------------------------
    EDD SALE COUNT
--------------------------------------------------*/
if ( !function_exists( 'aabbe_edd_sale_count' ) ) {
    function aabbe_edd_sale_count(){
        global $post;
        $download_id           = get_the_ID();

        $single_sales_count    = edd_get_download_sales_stats( get_the_ID() );
        $total_sales_count     = $edd_logs->get_log_count('*', 'file_sale');
        $single_sales_count    = $single_sales_count > 1 ? $single_sales_count .  __( ' Sales', 'aabbe' )  : $single_sales_count . __( ' Sale', 'aabbe' );
    }
}

/*-------------------------------------------------
    DEFAULT ORDERBY SHORING
---------------------------------------------------*/
if ( !function_exists('aabbe_download_orderby_shorting') ) {
    function aabbe_download_orderby_shorting() { ?>
        <div class="download__orderby__shoring__filter">
            <?php
                $old               = null;
                $price_low_to_high = null;
                $price_high_to_low = null;
                $popular           = null;
                $recent            = null;
                $title_A_to_Z      = null;
                $title_Z_to_A      = null;

                if( isset($_GET['orderby']) ){
                    if($_GET['orderby'] == "price_asc"){
                        $price_low_to_high = "selected";
                    }else if($_GET['orderby'] == "price_desc"){
                        $price_high_to_low = "selected";
                    }else if($_GET['orderby'] == "newness_asc"){
                        $recent = "selected";
                    }else if($_GET['orderby'] == "newness_desc"){
                        $old = "selected";
                    }else if($_GET['orderby'] == "sales"){
                        $popular = "selected";
                    }else if($_GET['orderby'] == "title_asc"){
                        $title_A_to_Z = "selected";
                    }else if($_GET['orderby'] == "title_desc"){
                        $title_Z_to_A = "selected";
                    }
                }else{
                    $old="selected";
                }
            ?>
           <select class="donwload__orderby__shorting" onchange="if (this.value) window.location.href=this.value">
                <option <?php echo esc_html($popular); ?> value="<?php echo esc_url(add_query_arg(array( 'orderby'=>'sales'))); ?>"><?php esc_html_e('Popular','aabbe'); ?></option>
                <option <?php echo esc_html($old); ?> value="<?php echo esc_url(add_query_arg(array( 'orderby'=>'newness_desc'))); ?>"><?php esc_html_e('Recent','aabbe'); ?></option>
                <option <?php echo esc_html($recent); ?>  value="<?php echo esc_url(add_query_arg(array( 'orderby'=>'newness_asc'))); ?>"><?php esc_html_e('Older','aabbe'); ?></option>
                <option <?php echo esc_html($price_low_to_high); ?> value="<?php echo esc_url(add_query_arg(array( 'orderby'=>'price_asc'))); ?>"><?php esc_html_e('Price (Low to High)','aabbe'); ?></option>
                <option <?php echo esc_html($price_high_to_low); ?> value="<?php echo esc_url(add_query_arg(array( 'orderby'=>'price_desc'))); ?>"><?php esc_html_e('Price (High to Low)','aabbe'); ?></option>
                <option <?php echo esc_html($title_A_to_Z); ?>  value="<?php echo esc_url(add_query_arg(array( 'orderby'=>'title_asc'))); ?>"><?php esc_html_e('Title (A - Z)','aabbe'); ?></option>
                <option <?php echo esc_html($title_Z_to_A); ?> value="<?php echo esc_url(add_query_arg(array( 'orderby'=>'title_desc'))); ?>"><?php esc_html_e('Title (Z - A)','aabbe'); ?></option>
            </select>
        </div>
        <?php 
    }
}

/*-------------------------------------------------
    DOWNLOAD CAGEGORY SHORING
---------------------------------------------------*/
if ( !function_exists('aabbe_download_category_shoring') ) {
    function aabbe_category_shorting(){ ?>
        <div class="download__category__shorting__filter">
            <?php if( $terms = get_terms( 'download_category', array( 'hide_empty' => true, )) ) :  ?>
                <select name="categoryfilter" class="download__category__shorting" onchange="if (this.value) window.location.href=this.value">
                    <option value=null><?php esc_html_e( 'Select category', 'aabbe' ) ?></option>
                    <?php foreach ( $terms as $term ) : ?>
                    <option name="categoryfilter" value="<?php echo esc_url(add_query_arg(array( 'download_category'=>$term->slug))); ?>"><?php echo esc_html($term->name) ?></option>
                    <?php endforeach; ?>
                </select>
            <?php endif; ?>
        </div>
    <?php
    }
}

/**
 * Get the parameters for ordering that we'll include in our select field
 * 
 * @since 1.0.0
 * @return Array
 */
function aabbe_edd_orderby_params() {
    $params = array( 
        'newness_asc' => array( 
            'id'      => 'newness_asc',
            'title'   => esc_html__( 'Newest first', 'aabbe' ),
            'orderby' => 'post_date',
            'order'   => 'DESC'
        ),
        'newness_desc' => array(
            'id'      => 'newness_desc',
            'title'   => esc_html__( 'Oldest first', 'aabbe' ),
            'orderby' => 'post_date',
            'order'   => 'ASC'
        ),
        'price_asc' => array(
            'id'      => 'price_asc',
            'title'   => esc_html__( 'Price (Lowest to Highest)', 'aabbe' ),
            'orderby' => 'meta_value_num',
            'order'   => 'ASC'
        ),
        'price_desc' => array(
            'id'      => 'price_desc',
            'title'   => esc_html__( 'Price (Highest to Lowest)', 'aabbe' ),
            'orderby' => 'meta_value_num',
            'order'   => 'DESC'
        ),
        'title_asc' => array(
            'id'      => 'title_asc',
            'title'   => esc_html__( 'Title (A - Z)', 'aabbe' ),
            'orderby' => 'title',
            'order'   => 'ASC'
        ),
        'title_desc' => array(
            'id'      => 'title_desc',
            'title'   => esc_html__( 'Title (Z - A)', 'aabbe' ),
            'orderby' => 'title',
            'order'   => 'DESC'
        )
    );
    $params = apply_filters( 'aabbe_edd_filter_orderby_params', $params );
    return $params;
}


/**
 * Filter the [downloads] query
 * @since 1.0.0
 * @param $query The query to filter
 * @param $atts The shortcode atts
*/
function aabbe_edd_filter_query( $query, $atts ) { 
    if( isset( $_GET['aabbe_orderby'] ) ) {
        $params  = aabbe_edd_orderby_params();
        $orderby = $_GET['aabbe_orderby'];
        if( isset( $params[$orderby] ) ) {
            $param = $params[$orderby];
            $query['orderby'] = esc_attr( $param['orderby'] );
            $query['order']   = esc_attr( $param['order'] );
            if( strpos( $param['id'], 'price' ) !== false ) {
                $query['meta_key'] = 'edd_price';
            }
        }
    }
    return $query;
}
add_filter( 'edd_downloads_query', 'aabbe_edd_filter_query', 10, 2 );

/**
 * Filter the [downloads] shortcode to add dropdown field 
 * @since 1.0.0
 * @param $display The markup to print
*/
function aabbe_edd_add_dropdown( $display ) {
    $orderby = '';
    if( isset( $_GET['aabbe_orderby'] ) ) {
        $orderby = $_GET['aabbe_orderby'];
    }
    // Get the array of parameters
    $params = aabbe_edd_orderby_params();
    $select = '';
    if( ! empty( $params ) ) {
        $select = '<form class="download__filter__edd__sorting">';
            $select .= '<select class="donload__orderby" name="aabbe_orderby">';
            foreach( $params as $param ) {
                $select .= '<option value="' . $param['id'] . '" ' . selected( $param['id'], $orderby, false ) . '>' . $param['title'] . '</option>';
            }
            $select .= '</select>';
        $select .= '</form>';
        $select .= '<script>
            jQuery(document).ready(function($) {
                $(".donload__orderby").change( function(){
                    $(this).closest("form").submit();
                });
            });
        </script>';
        $display = $select . $display;
    }
    return $display; 
}
add_filter( 'downloads_shortcode', 'aabbe_edd_add_dropdown', 10, 1 );


/*----------------------------------------------------
    EDD VARIABLE PRICE DROPDOWN
----------------------------------------------------*/
function aabbe_edd_purchase_variable_pricing( $download_id ) {
    $variable_pricing = edd_has_variable_prices( $download_id );

    if ( ! $variable_pricing )
        return;

    $prices = apply_filters( 'edd_purchase_variable_prices', edd_get_variable_prices( $download_id ), $download_id );
    $type   = edd_single_price_option_mode( $download_id ) ? 'checkbox' : 'radio';

    do_action( 'edd_before_price_options', $download_id );

    echo '<div class="edd_price_options">';
        if ( $prices ) {
            echo '<select>';
            foreach ( $prices as $key => $price ) {
                printf(
                    '<option id="%3$s" class="%4$s" value="%5$s" %7$s> %6$s</option>',
                    checked( 0, $key, false ),
                    $type,
                    esc_attr( 'edd_price_option_' . $download_id . '_' . $key ),
                    esc_attr( 'edd_price_option_' . $download_id ),
                    esc_attr( $key ),
                    esc_html( $price['name'] . ' - ' . edd_currency_filter( edd_format_amount( $price[ 'amount' ] ) ) ),
                    selected( isset( $_GET['price_option'] ), $key, false )
                );
                do_action( 'edd_after_price_option', $key, $price, $download_id );
            }
            echo '</select>';
        }
        do_action( 'edd_after_price_options_list', $download_id, $prices, $type );

    echo '</div>';
    do_action( 'edd_after_price_options', $download_id );
}
add_action( 'edd_purchase_link_top', 'aabbe_edd_purchase_variable_pricing', 10, 1 );
remove_action( 'edd_purchase_link_top', 'edd_purchase_variable_pricing', 10, 1 );


/*--------------------------------------------------
    VARIABLE PRICE DESCRIPTION
---------------------------------------------------*/
function aabbe_varibale_price_desc($download_id){
    if ( edd_has_variable_prices($download_id) && aabbe_any_switch('edd_show_variable_price_desc') == true  ) {
        echo '<p class="price__description">'.esc_html( aabbe_any_data('edd_variable_price_desc') ).'</p>';
    }
}
add_action( 'edd_after_price_options', 'aabbe_varibale_price_desc' );


/*---------------------------------------------------
    REMOVE PRICE FROM EDD BUY NOW BUTTON
-----------------------------------------------------*/
function aabbe_remove_price_purchase_button( $options ){
    $options['price'] = false;
    return $options;
}
add_filter( 'edd_purchase_link_defaults', 'aabbe_remove_price_purchase_button' );


/*--------------------------------------------------
    DOWNLOAD DROPDOWN CATEGORY
--------------------------------------------------*/
function aabbe_get_terms_dropdown($taxonomies, $args){
    $myterms = get_terms( $taxonomies, $args );
    $output  = "<div class='download__search__cats '><select name='download_cats'>";
    $output .= "<option value='all'>" . esc_html__("All Categories", 'aabbe') . "</option>";
    foreach ($myterms as $term) {
        $term_name = $term->name;
        $slug      = $term->slug;
        $output   .= "<option value='" . $slug . "'>" . $term_name . "</option>";
    }
    $output .= "</select></div>";
    return $output;
}


/*------------------------------------------------
    CUSTOMIZE DEFAULT SEARCH QUERY
-------------------------------------------------*/
function aabbe_category_search_query( $query ) {
    if( !isset($query->query['post_type']) ){
        return;
    }
    if ( $query->query['post_type'] != 'download' ) {
        return;
    }
    $query_var = (isset( $_GET['download_cats'] )) ? $_GET['download_cats'] : null;

    if ( $query_var == 'all' ) {
        return;
    }

    if ( $query->is_search() && $query->is_main_query() && isset( $_GET['download_cats'] ) ) {
        $taxquery = array(
            array(
                'taxonomy' => 'download_category',
                'field' => 'name',
                'terms' => array( $query_var ),
            )
        );
        $query->set( 'tax_query', $taxquery );
    }
}
add_action( 'pre_get_posts', 'aabbe_category_search_query' );


/*------------------------------------------------
    Remove Microdata From Html
-------------------------------------------------*/
add_filter( 'edd_add_schema_microdata', '__return_false' );

/*-------------------------------------------------
    PRODUCT RELATED POST QUERY
--------------------------------------------------*/
if ( !function_exists('aabbe_related_download_query') ) {
    function aabbe_related_download_query(){
        global $post;

        $custom_tax_terms = wp_get_object_terms( $post->ID, 'download_tag', array('fields' => 'ids') );

        $args = array(
            'post_type'           => 'download',
            'post_status'         => 'publish',
            'posts_per_page'      => 10,
            'orderby'             => 'rand',
            'ignore_sticky_posts' => 1,
            'tax_query'           => array(
                array(
                    'taxonomy' => 'download_tag',
                    'field'    => 'id',
                    'terms'    => $custom_tax_terms
                )
            ),
            'post__not_in' => array ($post->ID),
        );
        $related_posts = new WP_Query( $args ); ?>

        <?php if( $related_posts->have_posts() ) : ?>

            <div class="related__download__products__warapper">
                <h3><?php esc_html_e( 'You May Interested In', 'aabbe' ); ?></h3>
                <div class="related__download__products">
    <?php while($related_posts->have_posts()) : 
        $related_posts->the_post(); ?>

                    <div class="single__related__product">
                        <?php
                            $product_thumb = get_post_meta( get_the_id(), '_thumbnail', true );
                            if (is_array($product_thumb)) {
                                $product_thumbnail = wp_get_attachment_image_url( $product_thumb[0],'quomodo-edd-thumb' );
                            }else{
                                $product_thumbnail = wp_get_attachment_image_url( $product_thumb,'quomodo-edd-thumb' );
                            }
                        ?>
                        <?php if( !empty($product_thumbnail) ) : ?>
                            <a href="<?php the_permalink( get_the_id() ); ?>" class="ultimate__toltip__modal" data-tooltip-content="#tooltip_content_<?php the_id(); ?>">
                                <img src="<?php echo esc_url($product_thumbnail); ?>" alt="<?php the_title_attribute(); ?>">
                            </a>
                        <?php else: ?>
                            <a href="<?php the_permalink( get_the_id() ); ?>" class="ultimate__toltip__modal" data-tooltip-content="#tooltip_content_<?php the_id(); ?>"><?php the_post_thumbnail( 'thumbnail'); ?></a>
                        <?php endif; ?>

                        <div class="ultimate__toltip__modal__content" style="display: none;">
                            <div class="ultimate__toptip__inner" id="tooltip_content_<?php the_id(); ?>">
                                <?php get_template_part( 'edd/content/content', 'download' ); ?>
                            </div>
                        </div>
                    </div>

    <?php endwhile; ?>
                </div>
            </div>

        <?php endif; ?>
    <?php
    wp_reset_postdata();
    }
}

/*--------------------------------
    ADD CUSTOM ITEM IN MENU
---------------------------------*/
function aabbe_add_loginout_link( $items, $args ) {
    if ( is_user_logged_in() && $args->theme_location == 'user_menu_after_login' ) {
        $items .= '<li><a href="'. esc_url( wp_logout_url() ) .'">'.esc_html__( 'Log Out', 'aabbe' ).'</a></li>';
    }
    return $items;
}
add_filter( 'wp_nav_menu_items', 'aabbe_add_loginout_link', 10, 2 );


/*--------------------------------
    GET VIMEO VIDEO ID
----------------------------------*/
function aabbe_vimeo_url_id( $url = '' ) {
    $get_id = array();
    $id = '';
    if (preg_match('%^https?:\/\/(?:www\.|player\.)?vimeo.com\/(?:channels\/(?:\w+\/)?|groups\/([^\/]*)\/videos\/|album\/(\d+)\/video\/|video\/|)(\d+)(?:$|\/|\?)(?:[?]?.*)$%im', $url, $get_id)) {
        $id = $get_id[3];
    }
    return $id;
}

/*--------------------------------
    GET YOUTUBE VIDEO ID
----------------------------------*/
function aabbe_youtube_url_id( $url = '' ) {
    $get_id = array();
    $id = '';
    if (preg_match("#(?<=v=)[a-zA-Z0-9-]+(?=&)|(?<=v\/)[^&\n]+|(?<=v=)[^&\n]+|(?<=youtu.be/)[^&\n]+#", $url, $get_id )) {
        $id = $get_id[0];
    }
    return $id;
}